import { readFile, writeFile } from 'fs';
import { promisify } from 'util';
import path from 'path';
const fsReadFile = promisify(readFile);
const fsWriteFile = promisify(writeFile);
import deepmerge from 'deepmerge';
const PKG_FILE = () => path.resolve(process.env.CLI_CWD || process.cwd(), 'package.json');
export var pkgjson;
(function (pkgjson) {
    /**
     * Attempt to load the package.json at the current directory
     * @returns {NPM.Static|Boolean} The package as json, or false if it cannot be found
     * or loaded correctly
    */
    pkgjson.read = async () => {
        return new Promise((res, rej) => {
            fsReadFile(PKG_FILE())
                .catch(e => {
                res(false);
            })
                .then(json => {
                if (json)
                    res(json.toJSON());
                else
                    return false;
            });
        });
    };
    /**
     * Merge/create the package.json file
     * @param file JSON config for Origami app to override
     */
    pkgjson.write = async (file) => {
        let existing = {};
        try {
            existing = require(PKG_FILE());
        }
        catch (e) {
            // No existing package.json file
        }
        const TAB_SIZE = 4;
        return fsWriteFile(PKG_FILE(), JSON.stringify(deepmerge(existing, file), null, TAB_SIZE));
    };
})(pkgjson || (pkgjson = {}));
//# sourceMappingURL=packageFile.js.map